import _extends from "@babel/runtime/helpers/esm/extends";
import htmr from 'htmr';

// This is a list of all the elements that should not be allowed to be rendered as they pose a security risk.
// See: https://developer.mozilla.org/en-US/docs/Web/HTML/Element
// If you want to allow one of these elements, you can add it to the `transform` object in the `options`.
export var DANGEROUS_TRANSFORMS = {
  area: function area() {
    return null;
  },
  audio: function audio() {
    return null;
  },
  base: function base() {
    return null;
  },
  canvas: function canvas() {
    return null;
  },
  embed: function embed() {
    return null;
  },
  form: function form() {
    return null;
  },
  frame: function frame() {
    return null;
  },
  frameset: function frameset() {
    return null;
  },
  head: function head() {
    return null;
  },
  html: function html() {
    return null;
  },
  iframe: function iframe() {
    return null;
  },
  img: function img() {
    return null;
  },
  link: function link() {
    return null;
  },
  map: function map() {
    return null;
  },
  meta: function meta() {
    return null;
  },
  noscript: function noscript() {
    return null;
  },
  object: function object() {
    return null;
  },
  picture: function picture() {
    return null;
  },
  portal: function portal() {
    return null;
  },
  script: function script() {
    return null;
  },
  slot: function slot() {
    return null;
  },
  source: function source() {
    return null;
  },
  style: function style() {
    return null;
  },
  template: function template() {
    return null;
  },
  title: function title() {
    return null;
  },
  track: function track() {
    return null;
  },
  video: function video() {
    return null;
  }
};
export var htmlStringToReactElement = function htmlStringToReactElement(string, options) {
  return htmr(string, _extends({}, options, {
    transform: _extends({}, DANGEROUS_TRANSFORMS, options == null ? void 0 : options.transform)
  }));
};
var isReactRefObj = function isReactRefObj(target) {
  if (target && typeof target === 'object') {
    return 'current' in target;
  }
  return false;
};
var findDOMElements = function findDOMElements(target) {
  if (isReactRefObj(target)) return target.current;
  if (typeof target === 'string') {
    var selection = document.querySelectorAll(target);
    if (!selection.length) selection = document.querySelectorAll("#" + target);
    if (!selection.length) {
      throw new Error("The target '" + target + "' could not be identified in the dom, tip: check spelling");
    }
    return selection;
  }
  return target;
};
var isArrayOrNodeList = function isArrayOrNodeList(els) {
  if (els === null) return false;
  return Array.isArray(els) || typeof els.length === 'number';
};
export var getTarget = function getTarget(target) {
  var els = findDOMElements(target);
  if (isArrayOrNodeList(els)) {
    return els[0];
  }
  return els;
};