import { remove as removeAccents } from 'remove-accents';

// given a value and a query, if value has the query as a subset highlight it using startTag and endTag
export var highlightText = function highlightText(_ref) {
  var value = _ref.value,
    query = _ref.query,
    startTag = _ref.startTag,
    endTag = _ref.endTag;
  // replace accents and lowercase
  var queryWithoutAccents = removeAccents(query).toLowerCase();
  var valueWithoutAccents = removeAccents(value).toLowerCase();
  // get all the matches of the query in the value
  var matches = findMatches(valueWithoutAccents, queryWithoutAccents);
  var tagsLength = (startTag + endTag).length;
  // highlight the matches of the query in the value
  var highlighterReducer = function highlighterReducer(valueHighlightedAccumulator, match, i) {
    var start = match.start + i * tagsLength;
    var end = match.end + i * tagsLength;
    return "" + valueHighlightedAccumulator.slice(0, start) + startTag + valueHighlightedAccumulator.slice(start, end) + endTag + value.slice(match.end);
  };
  return matches.reduce(highlighterReducer, value);
};
var findMatches = function findMatches(value, query) {
  var from = 0;
  var matches = [];
  var match;
  while (match = findMatch(value, query, from)) {
    matches.push(match);
    from = match.end;
  }
  return matches;
};
var findMatch = function findMatch(value, query, from) {
  if (from === void 0) {
    from = 0;
  }
  var startingPosition = value.indexOf(query, from);
  var isQueryEmpty = query === '';
  if (startingPosition < 0 || isQueryEmpty) {
    return null;
  }
  var endingPosition = startingPosition + query.length;
  // return matched start and end index
  return {
    start: startingPosition,
    end: endingPosition
  };
};